@@ -3,7 +3,7 @@ package POE::Wheel::Run;
 use strict;
 
 use vars qw($VERSION @ISA);
-$VERSION = '1.311'; # NOTE - Should be #.### (three decimal places)
+$VERSION = '1.312'; # NOTE - Should be #.### (three decimal places)
 
 use Carp qw(carp croak);
 use POSIX qw(
@@ -256,16 +256,15 @@ sub new {
     );
   }
 
-#  # Did the user mangle stdio?
-#  # TODO - This means well, but it doesn't realy work.
-#  unless (ref($program) eq 'CODE') {
-#    croak "Someone has closed or moved STDIN... exec() won't find it"
-#      unless fileno(STDIN) or fileno(STDIN) != 0;
-#    croak "Someone has closed or moved STDOUT... exec() won't find it"
-#      unless fileno(STDOUT) or fileno(STDOUT) != 1;
-#    croak "Someone has closed or moved STDERR... exec() won't find it"
-#      unless fileno(STDERR) or fileno(STDERR) != 2;
-#  }
+  # Did the user mangle stdio?
+  unless (ref($program) eq 'CODE') {
+    croak "Someone has closed or moved STDIN... exec() won't find it"
+      unless defined fileno(STDIN) && fileno(STDIN) == 0;
+    croak "Someone has closed or moved STDOUT... exec() won't find it"
+      unless tied(*STDOUT) || defined fileno(STDOUT) && fileno(STDOUT) == 1;
+    croak "Someone has closed or moved STDERR... exec() won't find it"
+      unless tied(*STDERR) || defined fileno(STDERR) && fileno(STDERR) == 2;
+  }
 
   my (
     $stdin_read, $stdout_write, $stdout_read, $stdin_write,
@@ -1205,6 +1204,9 @@ sub _redirect_child_stdio_in_hell {
 sub _redirect_child_stdio_sanely {
   my ($class, $stdin_read, $stdout_write, $stderr_write) = @_;
 
+  # Note: we use 2-arg open() below because Perl 5.6 doesn't recognize
+  # the '>&' and '<&' modes with a 3-arg open()
+
   # Redirect STDIN from the read end of the stdin pipe.
   open( STDIN, "<&" . fileno($stdin_read) )
     or $class->_warn_and_exit_child(
